Mistune v3
==========

A fast yet powerful Python Markdown parser with renderers and plugins.

Overview
--------

Convert Markdown to HTML with ease:

.. code-block:: python

    import mistune
    mistune.html(your_markdown_text)

Useful Links
------------

1. GitHub: https://github.com/lepture/mistune
2. Docs: https://mistune.lepture.com/

License
-------

Mistune is licensed under BSD. Please see LICENSE for licensing details.
